@@ -7,11 +7,11 @@
 * @author 	Bertrand Mansion <bmansion@mamasam.com>
 * @package	Config
 */
-// $Id: IniCommented.php,v 1.3 2003/03/21 18:01:09 mansion Exp $
+// $Id: IniCommented.php 203590 2005-12-24 02:16:58Z aashley $
 
 require_once('Config.php');
 
-$datasrc = '/path/to/php.ini';
+$datasrc = '/usr/local/php5/lib/php.ini';
 
 $phpIni = new Config();
 $root =& $phpIni->parseConfig($datasrc, 'inicommented');
@@ -22,4 +22,4 @@ if (PEAR::isError($root)) {
 // Convert your ini file to a php array config
 
 echo '<pre>'.$root->toString('phparray', array('name' => 'php_ini')).'</pre>';
-?>
\ No newline at end of file
+?>
